#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.general_knowledge_interfaces.expert_check import ExpertCheck
from pycatia.general_knowledge_interfaces.expert_rule import ExpertRule
from pycatia.general_knowledge_interfaces.expert_rule_set_runtime import ExpertRuleSetRuntime


class ExpertRuleSet(ExpertRuleSetRuntime):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                    GenKnowledgeInterfaces.ExpertRuleBaseComponentRuntime
                |                        GenKnowledgeInterfaces.ExpertRuleSetRuntime
                |                             ExpertRuleSet
                | 
                | Represents the ExpertRuleSet object which is the editable part of a RuleSet or
                | a RuleBase.
                | The following example shows how to access the RuleSet of the rule Base
                | RB1
                | 
                |  Dim CATDocs As Documents 
                |  Set CATDocs   = CATIA.Documents
                |  Dim partdoc As Document
                |  Set partdoc   = CATDocs.Add("CATPart")
                |  Dim part as Part
                |  Set part      = partdoc.Part
                |  Dim relations as Relations
                |  Set relations = part.Relations
                |  Dim RuleBase as ExpertRuleBaseRuntime
                |  Set RuleBase  = relations.Item("RB1")
                |  Dim RuleSet as ExpertRuleSet
                |  Set RuleSet	 = RuleBase.RuleSet
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.expert_rule_set = com_object

    def create_check(self, i_name: str, i_check_variables: str, i_check_body: str, i_rule_set: str) -> ExpertCheck:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateCheck(CATBSTR iName,
                | CATBSTR iCheckVariables,
                | CATBSTR iCheckBody,
                | CATBSTR iRuleSet) As ExpertCheck
                | 
                |     Creates a check and adds it to the RuleSet.
                | 
                |     Parameters:
                | 
                |         iName
                |             The check name 
                |         iCheckVariables
                |             define variables of the check. 
                |         iCheckBody
                |             The check definition 
                |         iRuleSet
                |             The ruleset name where the check is to be aggregated.
                |             If this macro is used from the RuleSet where we
                |             want to create the check, the param must be equal to value : "".
                | 
                |     Returns:
                |         The created check 
                |     Example:
                |         This example creates the SolidActivity check and adds it to the newly
                |         created RuleSet.1 RuleSet then creates the HoleActivity check and adds it to
                |         the newly created RuleSet.2 RuleSet
                | 
                |           Dim CATDocs As Documents 
                |           Set CATDocs   = CATIA.Documents
                |           Dim partdoc As Document
                |           Dim part as Part
                |           Dim CheckSolid as ExpertCheck
                |           Dim ruleset as ExpertRuleSet
                |           Dim CheckHole as ExpertCheck
                | 
                |           Set partdoc      = CATDocs.Add("CATPart")
                |           Set part         = partdoc.Part 
                |           Set CheckSolid   = part.Relations.Item("RuleBase").RuleSet.CreateCheck
                |                              ("SolidActivity",
                |                               "Sol : Solid",
                |                               "Sol.Activity == True",
                |                               "RuleSet.1")
                |           Set ruleset      = part.Relations.Item("RuleBase").RuleSet.CreateRuleSet
                |                              ("RuleSet.2",
                |                               "")
                |           Set CheckHole    = ruleset.CreateCheck
                |                              ("HoleActivity",
                |                               "H : Hole",
                |                               "H.Activity == True",
                |                               "")

        :param str i_name:
        :param str i_check_variables:
        :param str i_check_body:
        :param str i_rule_set:
        :rtype: ExpertCheck
        """
        return ExpertCheck(self.expert_rule_set.CreateCheck(i_name, i_check_variables, i_check_body, i_rule_set))

    def create_rule(self, i_name: str, i_rule_variables: str, i_rule_body: str, i_rule_set: str) -> ExpertRule:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateRule(CATBSTR iName,
                | CATBSTR iRuleVariables,
                | CATBSTR iRuleBody,
                | CATBSTR iRuleSet) As ExpertRule
                | 
                |     Creates a rule and adds it to the RuleSet.
                | 
                |     Parameters:
                | 
                |         iName
                |             The rule name 
                |         iRuleVariables
                |             define variables of the rule. 
                |         iRuleBody
                |             The check definition 
                |         iRuleSet
                |             The RuleSet name where this rule aggregated. If this macro is used from the ruleset where
                |             we want to aggregate the rule, the param must be equal to value : "".
                | 
                |     Returns:
                |         The created rule 
                |     Example:
                |         This example creates the DesactivateIfActivatedOnSolid rule and adds it
                |         to the newly created RuleSet.1 RuleSet then creates the
                |         DesactivateIfActivatedOnHole rule and adds it to the newly created RuleSet.2
                |         RuleSet
                | 
                |           Dim CATDocs As Documents 
                |           Set CATDocs   = CATIA.Documents
                | 
                |           Dim partdoc As Document
                |           Set partdoc   = CATDocs.Add("CATPart")
                | 
                |           Dim part as Part
                |           Set part         = partdoc.Part
                | 
                |           Dim rulesolid as ExpertRule
                |           Set rulesolid    = part.Relations.Item("RuleBase").RuleSet.CreateRule
                |                              ("DesactivateIfActivatedOnSolid",
                |                               "Sol : Solid",
                |                               "Sol.Activity == True then Sol.Activity = False",
                |         "RuleSet.1")
                |           Dim ruleset as ExpertRuleSet
                |           Set ruleset      = part.Relations.Item("RuleBase").RuleSet.CreateRuleSet
                |                              ("RuleSet.2",
                |                               "")
                |           Dim rulehole as ExpertRule
                |           Set rulehole     = ruleset.CreateRule
                |                              ("DesactivateIfActivatedOnHole",
                |                               "H : Hole",
                |                               "H.Activity == True then H.Activity = False",
                |                               "")

        :param str i_name:
        :param str i_rule_variables:
        :param str i_rule_body:
        :param str i_rule_set:
        :rtype: ExpertRule
        """
        return ExpertRule(self.expert_rule_set.CreateRule(i_name, i_rule_variables, i_rule_body, i_rule_set))

    def create_rule_set(self, i_name: str, i_rule_set: str) -> 'ExpertRuleSet':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateRuleSet(CATBSTR iName,
                | CATBSTR iRuleSet) As ExpertRuleSet
                | 
                |     Creates a RuleSet and adds it to the RuleSet.
                | 
                |     Parameters:
                | 
                |         iName
                |             The ruleset name 
                |         iRuleSet
                |             The ruleset name where this ruleset is to be aggregated. If this macro is used from the
                |             ruleset or the rulebase where we want to aggregate the ruleset, the param must be equal
                |             to value : "".
                | 
                |     Returns:
                |         The created ruleset 
                |     Example:
                |         This example, firstly, creates the RuleSet.1 RuleSet and adds it to the
                |         newly created RuleBase. Secondly, it creates RuleSet.2 RuleSet and adds it to
                |         the ruleset RuleSet.1
                | 
                |           Dim CATDocs As Documents 
                |           Set CATDocs   = CATIA.Documents
                |           Dim partdoc As Document
                |           Set partdoc   = CATDocs.Add("CATPart")
                |           Dim part as Part
                |           Set part         = partdoc.Part
                |           Dim RS1 as ExpertRuleSet
                |           RS1 = part.Relations.Item("RuleBase").RuleSet.CreateRuleSet
                |                              ("RuleSet.1",
                |                               "")
                |           Dim RS2 as ExpertRuleSet
                |           RS2 = part.Relations.Item("RuleBase").RuleSet.CreateRuleSet
                |                              ("RuleSet.2",
                |                               "RuleSet.1")

        :param str i_name:
        :param str i_rule_set:
        :rtype: ExpertRuleSet
        """
        return ExpertRuleSet(self.expert_rule_set.CreateRuleSet(i_name, i_rule_set))

    def __repr__(self):
        return f'ExpertRuleSet(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class VisPropertySet(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     VisPropertySet
                | 
                | Represents the graphic properties for the current selection.
                | Role: We retrieve the graphic properties of the current selection thanks to
                | Selection.VisProperties
                | 
                | The graphic properties are:
                | 
                |     The Color
                | 
                |     The Color is defined by 3 components (red,green,blue). Each component
                |     ranges from 0 to 255
                |     The Opacity
                | 
                |     The opacity is defined from 255 (total opacity) to 0 (total transparency).
                |     In Material visualization mode the transparency is real, so the element is
                |     truly more or less opaque. But in another visualization mode, the transparency
                |     is a simulation, so if the opacity is between 0 and 254 the element is
                |     transparent but with the same visual effect and if the opacity is 255 the
                |     element is opaque.
                |     The width of a line
                | 
                |     Each index defines a width customizable in Tools/Options.
                |     The type of a line
                | 
                |     Solid, Dashed, ...
                |     The symbol of a point
                | 
                |     Star, Dot, ... 
                | 
                | A partial modification of an object
                | A part (for example) contains faces, edges, lines, points. Interactively with
                | the Edit Properties command the end user can change their color, their line
                | type and so one. To go faster there is the Graphic Toolbar which contains a
                | sub-set of properties. So this interface follows the behavior of the graphic
                | toolbar. The color, the line type ... is applicated to the sub-element of the
                | object defined by the application, and that you can retrieve in the graphic
                | toolbar.
                | 
                | A multiple selection
                | When we modify a graphic property using the Setxxx methods, we modify one by
                | one each element of the current selection.
                | When we read a graphic property using the Getxxx methods, we retrieve an
                | information which is valid for all elements of the current
                | selection.
                | 
                | Real versus Visible graphic properties
                | Elements of the current selection are inside a specification
                | tree:
                | 
                |    Example :
                |     
                |    Product0
                |         Part1
                |            Part3
                |         Part2
                | 
                |  
                | 
                | In this sample, product0 and Part1 are nodes and Part3 and Part2 are
                | leaves.
                | Each element (node and leaf) of this tree has its own graphic properties: that
                | is the "Real" graphic properties.
                | But there is an inheritance mecanism, so each element has also "Visible"
                | graphic properties. An element can be displayed with an another graphic
                | properties that its real graphic properties.
                | 
                | The inheritance is the following:
                | From the root of the tree, the first node with an inheritance flag to 1, gives
                | its property to each element below it. For each graphic property there is an
                | independantly inheritance.
                | 
                |    Example with the color property: ( color inheritance flag,
                |    color)
                |     
                |    Product0    (1,red)
                |         Part1    (0,blue)
                |            Part3   (1,green)
                |         Part2    (0,Yellow)
                | 
                |  
                | 
                | In this sample the real colord of the product0 is red, blue for the part1,
                | green for the part3 and yellow for the part2. But the visible color of each
                | element is red, because the product0 gives the red color at all the
                | tree.
                | 
                | See also:
                |     Selection
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.vis_property_set = com_object

    def get_layer(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetLayer(CatVisLayerType oLayerType,
                | long oLayerValue) As CatVisPropertyStatus
                | 
                |     Returns the layer for the current selection.
                |     Note: This property is global for the object.
                | 
                |     Parameters:
                | 
                |         oLayerType
                |             the type of the layer
                |             When the type is equal to catVisLayerNone, the layer of the current
                |             selection is "none".
                |             When the type is equal to catVisLayerBasic, the layer of the
                |             currection selection is indicated by the following
                |             parameter.
                |         oLayerValue
                |             A value between 0 to 1000
                |             This parameter is usefull only when the type of the layer is
                |             catVisLayerBasic. 
                |
                |     Example:
                | 
                |           The following sample shows how to retrieve layer of current
                |           selection.
                |          
                |          Dim layer
                |          layer = CLng(0) 
                |          Dim layertype As CatVisLayerType
                |          Set visProperties1 = CATIA.ActiveDocument.Selection.VisProperties 
                |          visProperties1.GetLayer layertype, layer
                |          If (layertype = catVisLayerNone) Then 
                |          MsgBox "Layer None"
                |          End If
                |          If (layertype = catVisLayerBasic) Then 
                |          MsgBox "layer =" & layer
                |          End If

        :return:
        :rtype: tuple
        """
        return self.vis_property_set.GetLayer()

    def get_pick(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetPick(CatVisPropertyPick oPick) As
                | CatVisPropertyStatus
                | 
                |     Returns the state pick mode for the current selection.
                |     Note: This property is global for the object.
                | 
                |     Example:
                | 
                |           The following sample shows how to retrieve pick mode of current
                |           selection.
                |          
                | 
                |          Dim pickstate As CatVisPropertyPick
                |          Set visProperties1 = CATIA.ActiveDocument.Selection.VisProperties 
                |          visProperties1.GetPick pickstate
                |          MsgBox "pick = " & pickstate

        :return: enum cat_vis_property_status
        :rtype: int
        """
        return self.vis_property_set.GetPick()

    def get_real_color(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetRealColor(long oRed,
                | long oGreen,
                | long oBlue) As CatVisPropertyStatus
                | 
                |     Retrieves the real color for the current selection.
                | 
                |     Parameters:
                | 
                |         oRed
                |             A value between 0 and 255 
                |         oGreen
                |             A value between 0 and 255 
                |         oBlue
                |             A value between 0 and 255 
                |         oStatus
                |             Legal value:
                | 
                |             catVisPropertyDefined
                |                 All elements in the current selection have the same real color,
                |                 so oRed, oGreen and oBlue are valid 
                |             catVisPropertyUnDefined
                |                 The real color is not the same for all elements of the current
                |                 selection, so oRed, oGreen and oBlue are not valid
                |
                |     Example:
                |           The following sample shows how to retrieve real colors of current
                |           selection.
                |
                |          Dim r, g, b 
                |          r = CLng(0) 
                |          g = CLng(0) 
                |          b = CLng(0) 
                |          Set visProperties1 = CATIA.ActiveDocument.Selection.VisProperties 
                |          visProperties1.GetRealColor r, g, b 
                |          MsgBox "r = " & r & " g = " & g & " b = " & b

        :rtype: tuple
        """
        return self.vis_property_set.GetRealColor()

    def get_real_inheritance(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetRealInheritance(CatVisPropertyType iPropertyType,
                | long oInheritance) As CatVisPropertyStatus
                | 
                |     Retrieves the real inheritance flag for the current
                |     selection.
                | 
                |     Parameters:
                | 
                |         iPropertyType
                |             The type of property: Color, Opacity, Line Width, Line Type
                |         oInheritance
                |             0
                |                 No heritance 
                |             1
                |                 Heritance 
                |         oStatus
                |             Legal value:
                |             catVisPropertyDefined
                |                 All elements in the current selection have the same real
                |                 inheritance flag for the iPropertyType , so oInheritance is valid
                |             catVisPropertyUnDefined
                |                 The real inheritance flag for iPropertyType is not the same for
                |                 all elements of the current selection, so oInheritance is not valid
                |
                |     Example:
                | 
                |           The following sample shows how to retrieve inheritance of current
                |           selection.
                |
                |          Dim inhLineType, inhWidth, inhColor, inhOpacity
                |          inhLineType = CLng(0) 
                |          inhWidth = CLng(0) 
                |          inhColor = CLng(0) 
                |          inhOpacity = CLng(0) 
                |          Set visProperties1 = CATIA.ActiveDocument.Selection.VisProperties 
                |          visProperties1.GetRealInheritance catVisPropertyLineType,
                |          inhLineType
                |          visProperties1.GetRealInheritance catVisPropertyWidth,
                |          inhWidth
                |          visProperties1.GetRealInheritance catVisPropertyColor,
                |          inhColor
                |          visProperties1.GetRealInheritance catVisPropertyOpacity,
                |          inhOpacity
                |          MsgBox "Inheritance : linetype = " & inhLineType & "width =" & inhWidth & "Colour ="
                |                 & inhColor & "Opacity =" & inhOpacity

        :rtype: tuple
        """
        return self.vis_property_set.GetRealInheritance()

    def get_real_line_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetRealLineType(long oLineType) As
                | CatVisPropertyStatus
                | 
                |     Retrieves the real line type for the current selection.
                | 
                |     Parameters:
                | 
                |         oLineType
                |             The value ranges from 1 to 63. Each indice is a line type
                |             customizable in the page Tools/Options/General/Display/Line Type.
                |             
                |         oStatus
                |             Legal value:
                | 
                |             catVisPropertyDefined
                |                 All elements in the current selection have the same real line
                |                 type , so oLineType is valid 
                |             catVisPropertyUnDefined
                |                 The real line type is not the same for all elements of the
                |                 current selection, so oLineType is not valid 
                |             catVisProperty?
                |                 At least one element of the current selection is not concerned
                |                 by this property, so oLineType is not valid 
                | 
                |     Example:
                | 
                |           The following sample shows how to retrieve real line type of current
                |           selection.
                |          
                | 
                |          Dim linetype
                |          linetype = CLng(0) 
                |          Set visProperties1 = CATIA.ActiveDocument.Selection.VisProperties 
                |          visProperties1.GetRealLineType linetype
                |          MsgBox "linetype = " & linetype

        :rtype: int
        """
        return self.vis_property_set.GetRealLineType()

    def get_real_opacity(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetRealOpacity(long oOpacity) As CatVisPropertyStatus
                | 
                |     Retrieves the real opacity for the current selection.
                | 
                |     Parameters:
                | 
                |         oOpacity
                |             a value between 0 (total transparency) and 255 (total opacity)
                |             
                |         oStatus
                |             Legal value:
                | 
                |             catVisPropertyDefined
                |                 All elements in the current selection have the same real
                |                 opacity value, so oOpacity is valid 
                |             catVisPropertyUnDefined
                |                 The real opacity value is not the same for all elements of the
                |                 current selection, so oOpacity is not valid 
                |             catVisProperty?
                |                 At least one element of the current selection is not concerned
                |                 by this property, so oOpacity is not valid 
                | 
                |     Example:
                | 
                |           The following sample shows how to retrieve real opacity of current
                |           selection.
                |          
                | 
                |          Dim op
                |          op = CLng(0) 
                |          Set visProperties1 = CATIA.ActiveDocument.Selection.VisProperties 
                |          visProperties1.GetRealOpacity op 
                |          MsgBox "opacity = " & op

        :rtype: int
        """
        return self.vis_property_set.GetRealOpacity()

    def get_real_width(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetRealWidth(long oLineWidth) As CatVisPropertyStatus
                | 
                |     Retrieves the real line width for the current selection.
                | 
                |     Parameters:
                | 
                |         oLineWidth
                |             The value ranges from 1 to 63. Each indice is a thickness
                |             customizable in the page Tools/Options/General/Display/thickness.
                |             
                |         oStatus
                |             Legal value:
                | 
                |             catVisPropertyDefined
                |                 All elements in the current selection have the same real width
                |                 , so oLineWidth is valid 
                |             catVisPropertyUnDefined
                |                 The real width is not the same for all elements of the current
                |                 selection, so oLineWidth is not valid 
                |             catVisProperty?
                |                 At least one element of the current selection is not concerned
                |                 by this property, so oLineWidth is not valid 
                | 
                |     Example:
                | 
                |           The following sample shows how to retrieve real line width of current
                |           selection.
                |          
                | 
                |          Dim width
                |          width = CLng(0) 
                |          Set visProperties1 = CATIA.ActiveDocument.Selection.VisProperties 
                |          visProperties1.GetRealWidth width
                |          MsgBox "width = " & width

        :rtype: int
        """
        return self.vis_property_set.GetRealWidth()

    def get_show(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetShow(CatVisPropertyShow oShow) As
                | CatVisPropertyStatus
                | 
                |     Returns the state show mode for the current selection.
                |     Note: This property is global for the object.
                | 
                |     Example:
                | 
                |           The following sample shows how to retrieve show mode of current
                |           selection.
                |          
                | 
                |          Dim showstate As CatVisPropertyShow
                |          Set visProperties1 = CATIA.ActiveDocument.Selection.VisProperties 
                |          visProperties1.GetShow showstate
                |          MsgBox "show = " & showstate

        :rtype: int
        """
        return self.vis_property_set.GetShow()[1]

    def get_symbol_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetSymbolType(long oSymbolType) As
                | CatVisPropertyStatus
                | 
                |     Retrieves the symbol type for the current selection.
                | 
                |     Parameters:
                | 
                |     oSymbolType
                |         The symbol type. See SetSymbolType to have values.
                |     oStatus
                |         Legal value:
                | 
                |         catVisPropertyDefined
                |             All elements in the current selection have the same symbol type ,
                |             so oLineType is valid 
                |         catVisPropertiesUnDefined
                |             The symbol type is not the same for all elements of the current
                |             selection, so oLineType is not valid 
                |         catVisProperty?
                |             At least one element of the current selection is not concerned by
                |             this property, so oSymbolType is not valid 
                | 
                |     Example:
                | 
                |           The following sample shows how to retrieve symbol line type of
                |           current selection.
                |          
                | 
                |          Dim symbol
                |          symbol = CLng(0) 
                |          Set visProperties1 = CATIA.ActiveDocument.Selection.VisProperties 
                |          visProperties1.GetSymbolType symbol
                |          MsgBox "Symbol = " & symbol

        :rtype: int
        """
        return self.vis_property_set.GetSymbolType()

    def get_visible_color(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetVisibleColor(long oRed,
                | long oGreen,
                | long oBlue) As CatVisPropertyStatus
                | 
                |     Retrieves the displayed (visible) color for the current
                |     selection.
                | 
                |     Parameters:
                | 
                |         oRed
                |             a value between 0 and 255 
                |         oGreen
                |             a value between 0 and 255 
                |         oBlue
                |             a value between 0 and 255 
                |         oStatus
                |             Legal value:
                | 
                |             catVisPropertyDefined
                |                 All elements in the current selection have the same visible
                |                 color, so oRed, oGreen and oBlue are valid 
                |             catVisPropertyUnDefined
                |                 The visible color is not the same for all elements of the
                |                 current selection, so oRed, oGreen and oBlue are not valid
                |                 
                | 
                |     Example:
                | 
                |           The following sample shows how to retrieve displayed colors of
                |           current selection.
                |          
                | 
                |          Dim r, g, b 
                |          r = CLng(0) 
                |          g = CLng(0) 
                |          b = CLng(0) 
                |          Set visProperties1 = CATIA.ActiveDocument.Selection.VisProperties 
                |          visProperties1.GetVisibleColor r, g, b 
                |          MsgBox "r = " & r & " g = " & g & " b = " & b

        :rtype: int
        """
        return self.vis_property_set.GetVisibleColor()

    def get_visible_inheritance(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetVisibleInheritance(CatVisPropertyType
                | iPropertyType,
                | long oInheritance) As CatVisPropertyStatus
                | 
                |     Checks if the real property is hidden.
                | 
                |     Parameters:
                | 
                |         iPropertyType
                |             The type of property : Color, Opacity, Line Width, Line Type 
                |         oInheritance
                | 
                |             0
                |                 No heritance: All parents of each element of the current
                |                 selection have an inheritance flag to 0. 
                |             1
                |                 Heritance: one parent of each element, perhaps the element
                |                 itself, as a inheritance flag to 1. 
                | 
                |         oStatus
                |             Legal value:
                | 
                |             catVisPropertyDefined
                |                 All elements in the current selection have the same inheritance
                |                 flag for the iPropertyType , so oInheritance is valid
                |                 
                |             catVisPropertyUnDefined
                |                 The inheritance flag for iPropertyType is not the same for all
                |                 elements of the current selection, so oInheritance is not valid

        :rtype: int
        """
        return self.vis_property_set.GetVisibleInheritance()

    def get_visible_line_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetVisibleLineType(long oLineType) As
                | CatVisPropertyStatus
                | 
                |     Retrieves the displayed (visible) line type for the current
                |     selection.
                | 
                |     Parameters:
                | 
                |         oLineType
                |             A value ranges from 1 to 63. 
                |         oStatus
                |             Legal value:
                | 
                |             catVisPropertyDefined
                |                 All elements in the current selection have the same visible
                |                 line type , so oLineType is valid 
                |             catVisPropertyUnDefined
                |                 The visible line type is not the same for all elements of the
                |                 current selection, so oLineType is not valid 
                |             catVisProperty?
                |                 At least one element of the current selection is not concerned
                |                 by this property, so oLineType is not valid 
                | 
                |     Example:
                | 
                |           The following sample shows how to retrieve displayed line type of
                |           current selection.
                |          
                | 
                |          Dim linetype
                |          linetype = CLng(0) 
                |          Set visProperties1 = CATIA.ActiveDocument.Selection.VisProperties 
                |          visProperties1.GetVisibleLineType linetype
                |          MsgBox "linetype = " & linetype

        :rtype: int
        """
        return self.vis_property_set.GetVisibleLineType()

    def get_visible_opacity(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetVisibleOpacity(long oOpacity) As
                | CatVisPropertyStatus
                | 
                |     Retrieves the displayed (visible) opacity for the current
                |     selection.
                | 
                |     Parameters:
                | 
                |         oOpacity
                |             a value between 0 (total transparency) and 255 (total opacity)
                |             
                |         oStatus
                |             Legal value:
                | 
                |             catVisPropertyDefined
                |                 All elements in the current selection have the same visible
                |                 opacity value, so oOpacity is valid 
                |             catVisPropertyUnDefined
                |                 The visible opacity value is not the same for all elements of
                |                 the current selection, so oOpacity is not valid
                |                 
                |             catVisProperty?
                |                 At least one element of the current selection is not concerned
                |                 by this property, so oOpacity is not valid 
                | 
                |     Example:
                | 
                |           The following sample shows how to retrieve displayed opacity of
                |           current selection.
                |          
                | 
                |          Dim op
                |          op = CLng(0) 
                |          Set visProperties1 = CATIA.ActiveDocument.Selection.VisProperties 
                |          visProperties1.GetVisibleOpacity op 
                |          MsgBox "opacity = " & op

        :rtype: int
        """
        return self.vis_property_set.GetVisibleOpacity()

    def get_visible_width(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetVisibleWidth(long oLineWidth) As
                | CatVisPropertyStatus
                | 
                |     Retrieves the displayed (visible) line width for the current
                |     selection.
                | 
                |     Parameters:
                | 
                |         oLineWidth
                |             A value ranges from 1 to 63. 
                |         oStatus
                |             Legal value:
                | 
                |             catVisPropertyDefined
                |                 All elements in the current selection have the same visible
                |                 width , so oLineWidth is valid 
                |             catVisPropertyUnDefined
                |                 The visible width is not the same for all elements of the
                |                 current selection, so oLineWidth is not valid 
                |             catVisProperty?
                |                 At least one element of the current selection is not concerned
                |                 by this property, so oLineWidth is not valid 
                | 
                |     Example:
                | 
                |           The following sample shows how to retrieve displayed line width of
                |           current selection.
                |
                |          Dim width
                |          width = CLng(0) 
                |          Set visProperties1 = CATIA.ActiveDocument.Selection.VisProperties 
                |          visProperties1.GetVisibleWidth width
                |          MsgBox "width = " & width


        :rtype: int
        """
        return self.vis_property_set.GetVisibleWidth()

    def set_layer(self, i_layer_type: int, i_layer_value: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetLayer(CatVisLayerType iLayerType,
                | long iLayerValue)
                | 
                |     Sets the layer for the current selection.
                |     Note: This property is global for the object.
                | 
                |     Parameters:
                | 
                |         iLayerType
                |             the type of the layer 
                |         iLayerValue
                |             A value between 0 to 1000
                |             This parameter is used only when the type of the layer is
                |             catVisLayerBasic. 
                | 
                |     Example:
                | 
                |           The following sample shows how to change layer of current
                |           selection.
                |          
                | 
                |          Set visProperties1 = CATIA.ActiveDocument.Selection.VisProperties 
                |          visProperties1.SetLayer catVisLayerBasic, 100

        :param int i_layer_type: enum cat_vis_layer_type
        :param int i_layer_value:
        :rtype: None
        """
        return self.vis_property_set.SetLayer(i_layer_type, i_layer_value)

    def set_pick(self, i_pick: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetPick(CatVisPropertyPick iPick)
                | 
                |     Sets the state pick mode for the current selection.
                |     Note: This property is global for the object.
                | 
                |     Example:
                | 
                |           The following sample shows how to change pick mode of current
                |           selection.
                |          
                | 
                |          Set visProperties1 = CATIA.ActiveDocument.Selection.VisProperties 
                |          visProperties1.SetPick catVisPropertyNoPickAttr

        :param int i_pick: enum cat_vis_property_pick
        :rtype: None
        """
        return self.vis_property_set.SetPick(i_pick)

    def set_real_color(self, i_red: int, i_green: int, i_blue: int, i_inheritance: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetRealColor(long iRed,
                | long iGreen,
                | long iBlue,
                | long iInheritance)
                | 
                |     Sets the real color and the color inheritance flag for the current
                |     selection.
                | 
                |     Parameters:
                | 
                |         iRed
                |             A value between 0 and 255 
                |         iGreen
                |             A value between 0 and 255 
                |         iBlue
                |             A value between 0 and 255 
                |         iInheritance
                |             Legal value:
                | 
                |             0
                |                 No heritance 
                |             1
                |                 Heritance 
                | 
                |     Example:
                | 
                |           The following sample shows how to change colour of current
                |           selection.
                |          
                | 
                |          Set visProperties1 = CATIA.ActiveDocument.Selection.VisProperties 
                |          visProperties1.SetRealColor 255,0,0,1

        :param int i_red:
        :param int i_green:
        :param int i_blue:
        :param int i_inheritance:
        :rtype: None
        """
        return self.vis_property_set.SetRealColor(i_red, i_green, i_blue, i_inheritance)

    def set_real_line_type(self, i_line_type: int, i_inheritance: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetRealLineType(long iLineType,
                | long iInheritance)
                | 
                |     Sets the real line type and the line type inheritance flag for the current
                |     selection.
                | 
                |     Parameters:
                | 
                |         iLineType
                |             The value ranges from 1 to 63. Each indice is a line type
                |             customizable in the page Tools/Options/General/Display/Line Type.
                |             
                |         iInheritance
                |             Legal value:
                | 
                |             0
                |                 No heritance 
                |             1
                |                 Heritance 
                | 
                |     Example:
                | 
                |     The following sample shows how to change line type of current
                |     selection.
                |       Set visProperties1 = CATIA.ActiveDocument.Selection.VisProperties
                |       visProperties1.SetRealLineType 4,1

        :param int i_line_type:
        :param int i_inheritance:
        :rtype: None
        """
        return self.vis_property_set.SetRealLineType(i_line_type, i_inheritance)

    def set_real_opacity(self, i_opacity: int, i_inheritance: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetRealOpacity(long iOpacity,
                | long iInheritance)
                | 
                |     Sets the opacity and the opacity inheritance flag for the current
                |     selection.
                | 
                |     Parameters:
                | 
                |         iOpacity
                |             A value between 0 (total transparency) and 255 (total opacity).
                |             
                |         iInheritance
                |             Legal value:
                | 
                |             0
                |                 No heritance 
                | 
                |     Example:
                | 
                |           The following sample shows how to change opacity of current
                |           selection.
                |          
                | 
                |          Set visProperties1 = CATIA.ActiveDocument.Selection.VisProperties 
                |          visProperties1.SetRealOpacity 128,1

        :param int i_opacity:
        :param int i_inheritance:
        :rtype: None
        """
        return self.vis_property_set.SetRealOpacity(i_opacity, i_inheritance)

    def set_real_width(self, i_line_width: int, i_inheritance: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetRealWidth(long iLineWidth,
                | long iInheritance)
                | 
                |     Sets the real line width and the line width inheritance flag for the
                |     current selection.
                | 
                |     Parameters:
                | 
                |         iLineWidth
                |             The value ranges from 1 to 63. Each indice is a thickness
                |             customizable in the page Tools/Options/General/Display/thickness.
                |             
                |         iInheritance
                |             Legal value:
                | 
                |             0
                |                 No heritance 
                |             1
                |                 Heritance 
                | 
                |     Example:
                | 
                |           The following sample shows how to change line width of current
                |           selection.
                |          
                | 
                |          Set visProperties1 = CATIA.ActiveDocument.Selection.VisProperties 
                |          visProperties1.SetRealWidth 4,1

        :param int i_line_width:
        :param int i_inheritance:
        :rtype: None
        """
        return self.vis_property_set.SetRealWidth(i_line_width, i_inheritance)

    def set_show(self, i_show: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetShow(CatVisPropertyShow iShow)
                | 
                |     Sets the state show mode for the current selection.
                |     Note: This property is global for the object.
                | 
                |     Example:
                | 
                |           The following sample shows how to change show mode of current
                |           selection.
                |          
                | 
                |          Set visProperties1 = CATIA.ActiveDocument.Selection.VisProperties 
                |          visProperties1.SetShow catVisPropertyNoShowAttr

        :param int i_show: enum cat_vis_property_show
        :rtype: None
        """
        return self.vis_property_set.SetShow(i_show)

    def set_symbol_type(self, i_symbol_type: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetSymbolType(long iSymbolType)
                | 
                |     Sets the symbol type.
                |     Note:There is no heritage for symbols. That is why there is only one
                |     function "SetSymbolType" and no function "SetRealSymbolType" or
                |     "SetVisibleSymbolType"
                | 
                |     Parameters:
                | 
                |         iSymbolType
                |             The symbol type
                |             legal values:
                | 
                |                 1 : a cross which looks like a "X".
                |                 2 : a cross which looks like a "+"
                |                 3 : an unfilled circle
                |                 4 : two unfilled concentric circles
                |                 5 : a filled circle
                |                 6 : a filled square
                |                 7 : a star which is the union of a 2D marker CROSS ,a 2D marker PLUS and a 2D marker
                |                     DOT
                |                 8 : a dot
                |                 9 : a smalldot (one pixel)
                |                 10 : a kind of arrow which points to the bottom-left
                |                 
                |                 11 : a kind of arrow which points to the top-right
                | 
                |                 FULLCIRCLE2 : a big 12
                |                 FULLSQUARE2 : a big 13
                | 
                |     Example:
                |     The following sample shows how to change symbol type of current
                |     selection.
                |
                |       Set visProperties1 = CATIA.ActiveDocument.Selection.VisProperties
                |       visProperties1.SetSymbolType 4

        :param int i_symbol_type:
        :rtype: None
        """
        return self.vis_property_set.SetSymbolType(i_symbol_type)

    def __repr__(self):
        return f'VisPropertySet(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.in_interfaces.document import Document
from pycatia.system_interfaces.any_object import AnyObject


class ArrBomReport(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ArrBOMReport
                | 
                | The interface to access a CATIAArrBOMReport
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.arr_bom_report = com_object

    def generate_bom_report(self, i_document_to_extract_data: Document, i_output_file_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GenerateBOMReport(Document iDocumentToExtractData,
                | CATBSTR iOutputFileName)
                | 
                |     This method generate a BOM report on the current piping document to an
                |     output html file.

        :param Document i_document_to_extract_data:
        :param str i_output_file_name:
        :rtype: None
        """
        return self.arr_bom_report.GenerateBOMReport(i_document_to_extract_data.com_object, i_output_file_name)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'generate_bom_report'
        # # vba_code = """
        # # Public Function generate_bom_report(arr_bom_report)
        # #     Dim iDocumentToExtractData (2)
        # #     arr_bom_report.GenerateBOMReport iDocumentToExtractData
        # #     generate_bom_report = iDocumentToExtractData
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ArrBomReport(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_app_connector import SchAppConnector
from pycatia.cat_sch_platform_interfaces.sch_list_of_bst_rs import SchListOfBSTRs
from pycatia.cat_sch_platform_interfaces.sch_list_of_longs import SchListOfLongs
from pycatia.cat_sch_platform_interfaces.sch_list_of_objects import SchListOfObjects
from pycatia.in_interfaces.document import Document
from pycatia.system_interfaces.any_object import AnyObject


class SchAppCntrDocLink(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchAppCntrDocLink
                | 
                | Manage a schematic connector.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_app_cntr_doc_link = com_object

    def app_get_link(
            self,
            o_l_cntrs: SchListOfObjects,
            o_l_document_names: SchListOfBSTRs,
            o_publication_name: str
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppGetLink(SchListOfObjects oLCntrs,
                | SchListOfBSTRs oLDocumentNames,
                | CATBSTR oPublicationName)
                | 
                |     Deprecated:
                |         V5R18 Use SchAppCntrDocLink.AppGetLinkedDocs instead. Get a list of
                |         linked connector(s) and its document names or publication name.
                |         
                |     Parameters:
                | 
                |         oLCntrs
                |             A list of connectors that are linked to this connector.
                |             
                |         oLDocumentNames
                |             A list of document names containing the linked connector.
                |             
                |         oPublicationName
                |             The publication name of the connector(s) linked to this connector.
                |             
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppCntrDocLink
                |          Dim objArg1 As SchListOfObjects
                |          Dim objArg2 As SchListOfBSTRs
                |          Dim strVar3 As String
                |           ...
                |          objThisIntf.AppGetLinkobjArg1,objArg2,strVar3

        :param SchListOfObjects o_l_cntrs:
        :param SchListOfBSTRs o_l_document_names:
        :param str o_publication_name:
        :rtype: None
        """
        return self.sch_app_cntr_doc_link.AppGetLink(
            o_l_cntrs.com_object,
            o_l_document_names.com_object,
            o_publication_name
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_get_link'
        # # vba_code = """
        # # Public Function app_get_link(sch_app_cntr_doc_link)
        # #     Dim oLCntrs (2)
        # #     sch_app_cntr_doc_link.AppGetLink oLCntrs
        # #     app_get_link = oLCntrs
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def app_get_linked_docs(
            self,
            o_publication_name: str,
            o_l_document_name: SchListOfBSTRs,
            o_l_document_uuid: SchListOfBSTRs,
            o_l_open_status: SchListOfLongs,
            o_l_cntr: SchListOfObjects
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppGetLinkedDocs(CATBSTR oPublicationName,
                | SchListOfBSTRs oLDocumentName,
                | SchListOfBSTRs oLDocumentUuid,
                | SchListOfLongs oLOpenStatus,
                | SchListOfObjects oLCntr)
                | 
                |     Get a list of linked connectors, their documents' names, uuids, and 'open
                |     in session' statuses, and a publication name of the
                |     connectors.
                | 
                |     Parameters:
                | 
                |         oPublicationName
                |             The publication name of the connector(s) linked to this connector.
                |             
                |         oLDocumentName
                |             A list of document names of the documents containing the linked
                |             connector(s). 
                |         oLDocumentUuid
                |             A list of document UUIDs of the documents containing the linked
                |             connector(s). 
                |         oLOpenStatus
                |             A list of integer flags specifying whether a linked document is
                |             open in the session or not (1 - yes; 0 - no). 
                |         oLCntr
                |             A list of connectors that are linked to this connector.
                |             
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppCntrDocLink
                |          Dim strVar1 As String
                |          Dim objArg2 As SchListOfBSTRs
                |          Dim objArg3 As SchListOfBSTRs
                |          Dim objArg4 As SchListOfLongs
                |          Dim objArg5 As SchListOfObjects
                |           ...
                |          objThisIntf.AppGetLinkedDocsstrVar1,objArg2,objArg3,objArg4,objArg5

        :param str o_publication_name:
        :param SchListOfBSTRs o_l_document_name:
        :param SchListOfBSTRs o_l_document_uuid:
        :param SchListOfLongs o_l_open_status:
        :param SchListOfObjects o_l_cntr:
        :rtype: None
        """
        return self.sch_app_cntr_doc_link.AppGetLinkedDocs(
            o_publication_name,
            o_l_document_name.com_object,
            o_l_document_uuid.com_object,
            o_l_open_status.com_object,
            o_l_cntr.com_object
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_get_linked_docs'
        # # vba_code = """
        # # Public Function app_get_linked_docs(sch_app_cntr_doc_link)
        # #     Dim oPublicationName (2)
        # #     sch_app_cntr_doc_link.AppGetLinkedDocs oPublicationName
        # #     app_get_linked_docs = oPublicationName
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def app_is_linkable(self, i_sch_connector: SchAppConnector, o_b_yes: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppIsLinkable(SchAppConnector iSchConnector,
                | boolean oBYes)
                | 
                |     Query whether this connector and input connector can be
                |     linked.
                | 
                |     Parameters:
                | 
                |         iSchConnector
                |             The connector to link to. 
                |         oBYes
                |             If TRUE, connectors can be linked. 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppCntrDocLink
                |          Dim objArg1 As SchAppConnector
                |          Dim bVar2 As boolean
                |           ...
                |          objThisIntf.AppIsLinkableobjArg1,bVar2

        :param SchAppConnector i_sch_connector:
        :param bool o_b_yes:
        :rtype: None
        """
        return self.sch_app_cntr_doc_link.AppIsLinkable(i_sch_connector.com_object, o_b_yes)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_is_linkable'
        # # vba_code = """
        # # Public Function app_is_linkable(sch_app_cntr_doc_link)
        # #     Dim iSchConnector (2)
        # #     sch_app_cntr_doc_link.AppIsLinkable iSchConnector
        # #     app_is_linkable = iSchConnector
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def app_link(self, i_sch_connector: SchAppConnector) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppLink(SchAppConnector iSchConnector)
                | 
                |     Create an external link to another connector.
                | 
                |     Parameters:
                | 
                |         iSchConnector
                |             The connector to link to. 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppCntrDocLink
                |          Dim objArg1 As SchAppConnector
                |           ...
                |          objThisIntf.AppLinkobjArg1

        :param SchAppConnector i_sch_connector:
        :rtype: None
        """
        return self.sch_app_cntr_doc_link.AppLink(i_sch_connector.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_link'
        # # vba_code = """
        # # Public Function app_link(sch_app_cntr_doc_link)
        # #     Dim iSchConnector (2)
        # #     sch_app_cntr_doc_link.AppLink iSchConnector
        # #     app_link = iSchConnector
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def app_link_init(self, i_publication_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppLinkInit(CATBSTR iPublicationName)
                | 
                |     Publish this connector to make it available for linking.
                | 
                |     Parameters:
                | 
                |         iPublicationName
                |             The publication name of connector. 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppCntrDocLink
                |          Dim strVar1 As String
                |           ...
                |          objThisIntf.AppLinkInitstrVar1

        :param str i_publication_name:
        :rtype: None
        """
        return self.sch_app_cntr_doc_link.AppLinkInit(i_publication_name)

    def app_open_linked_doc(self, i_document_name: str, i_document_uuid: str, o_document: Document) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppOpenLinkedDoc(CATBSTR iDocumentName,
                | CATBSTR iDocumentUuid,
                | Document oDocument)
                | 
                |     Open a linked document.
                | 
                |     Parameters:
                | 
                |         iDocumentName
                |             Name of the document (from oLDocumentName list in
                |             AppGetLinkedDocs). 
                |         iDocumentUuid
                |             Uuid of the document (from oLDocumentUuid list in
                |             AppGetLinkedDocs). 
                |         oDocument
                |             Pointer to the document. 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppCntrDocLink
                |          Dim strVar1 As String
                |          Dim strVar2 As String
                |          Dim objArg3 As Document
                |           ...
                |          objThisIntf.AppOpenLinkedDocstrVar1,strVar2,objArg3

        :param str i_document_name:
        :param str i_document_uuid:
        :param Document o_document:
        :rtype: None
        """
        return self.sch_app_cntr_doc_link.AppOpenLinkedDoc(i_document_name, i_document_uuid, o_document.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_open_linked_doc'
        # # vba_code = """
        # # Public Function app_open_linked_doc(sch_app_cntr_doc_link)
        # #     Dim iDocumentName (2)
        # #     sch_app_cntr_doc_link.AppOpenLinkedDoc iDocumentName
        # #     app_open_linked_doc = iDocumentName
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def app_un_link(self, i_unpublish: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppUnLink(long iUnpublish)
                | 
                |     Remove external link to another connector.
                | 
                |     Parameters:
                | 
                |         iUnpublish
                |             iUnpublish = 0, do not delete publication connector (default)
                |             iUnpublish > 0, delete publication connector
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppCntrDocLink
                |          Dim intVar1 As Integer
                |           ...
                |          objThisIntf.AppUnLinkintVar1

        :param int i_unpublish:
        :rtype: None
        """
        return self.sch_app_cntr_doc_link.AppUnLink(i_unpublish)

    def __repr__(self):
        return f'SchAppCntrDocLink(name="{self.name}")'



from pathlib import Path

from pycatia.dnb_human_modeling_interfaces.swk_human_catalog import SWKHumanCatalog
from pycatia.dnb_human_modeling_interfaces.swk_manikin import SWKManikin
from pycatia.system_interfaces.any_object import AnyObject


class SWKHmiWorkbench(AnyObject):
    """
    This class is not documented in the CAA V5 Visual Basic Help file.

    This class was created by referring to the Microsoft Visual Basic object explorer.
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.com_object = com_object

    def add_manikin_for_clash(self) -> SWKManikin:
        """
        .. note::
            :class: toggle

            Microsoft Visual Basic Object Browser
                | Sub AddManikinForClash(piManikin As SWKManikin)
                |    Member of SWKHumanModelingItf.SWKHmiWorkbench

        :rtype: SWKManikin
        """

        return self.com_object.AddManikinForClash()

    def clean_clash_results(self) -> None:
        """
        .. note::
            :class: toggle

            Microsoft Visual Basic Object Browser
                | Sub CleanClashResults()
                |     Member of SWKHumanModelingItf.SWKHmiWorkbench
        """

        return self.com_object.CleanClashResults()

    def compute_clash(self) -> int:
        """
        .. note::
            :class: toggle

            Microsoft Visual Basic Object Browser
                | Function ComputeClash(piMakeExplicitCall As Boolean) As Long
                |     Member of SWKHumanModelingItf.SWKHmiWorkbench
        """

        return self.com_object.ComputeClash()

    def create_color_from_rgb(self, pi_red: int, pi_green: int, pi_blue: int) -> int:
        """
        .. note::
            :class: toggle

            Microsoft Visual Basic Object Browser
                | Function CreateColorFromRGB(piRed As Long, piGreen As Long, piBlue As Long) As Long
                |    Member of SWKHumanModelingItf.SWKHmiWorkbench

        :param int pi_red:
        :param int pi_green:
        :param int pi_blue:
        :rtype: int
        """

        return self.com_object.CreateColorFromRGB(pi_red, pi_green, pi_blue)

    def create_left_forearm(
            self,
            pi_manikin_name: str,
            pi_sex: int,
            pi_percentile: float,
            pi_population: int
    ) -> SWKManikin:
        """
        .. note::
            :class: toggle

            Microsoft Visual Basic Object Browser
                | Function CreateLeftForearm(piManikinName As String,
                |                            piSex As SWKAnthroSex,
                |                            piPercentile As Double,
                |                            piPopulation As Long) As SWKManikin
                |     Member of SWKHumanModelingItf.SWKHmiWorkbench

        :param str pi_manikin_name:
        :param int pi_sex: enum swk_anthro_sex
        :param float pi_percentile:
        :param int pi_population:
        :rtype: SWKHumanCatalog
        """

        return SWKManikin(self.com_object.CreateLeftForearm(pi_manikin_name, pi_sex, pi_percentile, pi_population))

    def create_manikin(
            self,
            pi_manikin_name: str,
            pi_sex: int,
            pi_percentile: float,
            pi_population: int
    ) -> SWKManikin:
        """
        .. note::
            :class: toggle

            Microsoft Visual Basic Object Browser
                | Function CreateManikin(piManikinName As String,
                |                        piSex As SWKAnthroSex,
                |                        piPercentile As Double,
                |                        piPopulation As Long) As SWKManikin
                |     Member of SWKHumanModelingItf.SWKHmiWorkbench

        :param str pi_manikin_name:
        :param int pi_sex: enum swk_anthro_sex
        :param float pi_percentile:
        :param int pi_population:
        :rtype: SWKHumanCatalog
        """

        return SWKManikin(self.com_object.CreateManikin(pi_manikin_name, pi_sex, pi_percentile, pi_population))

    def create_right_forearm(
            self,
            pi_manikin_name: str,
            pi_sex: int,
            pi_percentile: float,
            pi_population: int) -> SWKManikin:
        """
        .. note::
            :class: toggle

            Microsoft Visual Basic Object Browser
                | Function CreateRightForearm(piManikinName As String,
                |                             piSex As SWKAnthroSex,
                |                             piPercentile As Double,
                |                             piPopulation As Long) As SWKManikin
                |     Member of SWKHumanModelingItf.SWKHmiWorkbench

        :param str pi_manikin_name:
        :param int pi_sex: enum swk_anthro_sex
        :param float pi_percentile:
        :param int pi_population:
        :rtype: SWKHumanCatalog
        """

        return SWKManikin(self.com_object.CreateRightForearm(pi_manikin_name, pi_sex, pi_percentile, pi_population))

    def new_human_catalog(self) -> SWKHumanCatalog:
        """

        .. note::
            :class: toggle

            Microsoft Visual Basic Object Browser
                | Function NewHumanCatalog(piPathFile As String) As SWKHumanCatalog
                |     Member of SWKHumanModelingItf.SWKHmiWorkbench

        :rtype: SWKHumanCatalog
        """

        return SWKHumanCatalog(self.com_object.NewHumanCatalog())

    def open_human_catalog(self, pi_path_file: Path, pi_doc_env: str) -> SWKHumanCatalog:
        """
        .. note::
            :class: toggle

            Microsoft Visual Basic Object Browser
                | Function OpenHumanCatalog(piPathFile As String, piDocEnv As String) As SWKHumanCatalog
                |     Member of SWKHumanModelingItf.SWKHmiWorkbench

        :param Path pi_path_file:
        :param Path pi_doc_env:
        :rtype: SWKHumanCatalog
        """

        return SWKHumanCatalog(self.com_object.OpenHumanCatalog(pi_path_file, pi_doc_env))

    def open_writable_human_catalog(self, pi_path_file: Path, pi_doc_env: str) -> SWKHumanCatalog:
        """
        .. note::
            :class: toggle

            Microsoft Visual Basic Object Browser
                | Function OpenWritableHumanCatalog(piPathFile As String, piDocEnv As String) As SWKHumanCatalog
                |     Member of SWKHumanModelingItf.SWKHmiWorkbench

        :param Path pi_path_file:
        :param Path pi_doc_env:
        :rtype: SWKHumanCatalog
        """

        return SWKHumanCatalog(self.com_object.OpenWritableHumanCatalog(pi_path_file, pi_doc_env))

    def reset_clash_list(self) -> None:
        """
        .. note::
            :class: toggle

            Microsoft Visual Basic Object Browser
                | Sub ResetClashList()
                |     Member of SWKHumanModelingItf.SWKHmiWorkbench

        :rtype: None
        """

        return self.com_object.ResetClashList()

    def set_clash_mode(self, pi_clash_mode) -> int:
        """
        .. note::
            :class: toggle

            Microsoft Visual Basic Object Browser
                | Sub SetClashMode(piClashMode As String)
                |     Member of SWKHumanModelingItf.SWKHmiWorkbench

        :param str pi_clash_mode:
        :rtype: None
        """

        return self.com_object.SetClashMode(pi_clash_mode)

    def start_command(self, pi_command_header_name: str) -> int:
        """
        .. note::
            :class: toggle

            Microsoft Visual Basic Object Browser
                | Sub StartCommand(piCommandHeaderName As String)
                |     Member of SWKHumanModelingItf.SWKHmiWorkbench

        :param str pi_command_header_name:
        :rtype: None
        """

        return self.com_object.StartCommand(pi_command_header_name)

    def stop_command(self, pi_command_header_name: str) -> None:
        """
        .. note::
            :class: toggle

            Microsoft Visual Basic Object Browser
                | Sub StopCommand(piCommandHeaderName As String)
                |     Member of SWKHumanModelingItf.SWKHmiWorkbench

        :param str pi_command_header_name:
        :rtype: None
        """

        return self.com_object.StopCommand(pi_command_header_name)

    def update(self) -> None:
        """
        .. note::
            :class: toggle

            Microsoft Visual Basic Object Browser
                | Sub Update()
                |     Member of SWKHumanModelingItf.SWKHmiWorkbench

        :rtype: None
        """

        return self.com_object.Update()

    def update_ppr_tree(self) -> None:
        """
        .. note::
            :class: toggle

            Microsoft Visual Basic Object Browser
                | Sub UpdatePPRTree()
                |     Member of SWKHumanModelingItf.SWKHmiWorkbench

        :rtype: None
        """

        return self.com_object.UpdatePPRTree()



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class InteropSettingAtt(SettingController):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         InteropSettingAtt
                | 
                | Represents the object to handle the setting parameters of the "V4 Data Reading"
                | tab page.
                | Role: This interface is implemented by a component named
                | CATV4IInteropSettingCtrl which represents the controller of the Setting. The
                | setting parameters of the tab are the following:
                | 
                |     "Display only elements with Sensitive Attribute"
                |     "Display 3D elements labels"
                |     "Open in Light Mode: 2D Data are not taken into account"
                |     "Reading Code page"
                |     "PROJECT File Path"
                |     "DLNAME"
                |     "Prj Warn"
                |     "Characters Equivalence Table Path"
                | 
                | To access this property page:
                | 
                |     Click the Options command in the Tools menu
                |     Click + left of General to unfold the workbench list
                |     Click Compatibility
                |
                | This interface defines:
                | 
                |     A method to get each parameter
                |     A method to set the value of each parameter
                |     A method to lock/unlock each parameter
                |     A method to retrieve the informations concerning each
                |     parameter
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.interop_setting_att = com_object

    @property
    def code_page(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Code_page() As CATBSTR
                | 
                |     Retrieves or sets the value of the "Reading Code page" setting
                |     parameter.
                |     Role: The "Reading Code page" declares the language to identify the data
                |     read if this data is not labeled. It is stored in the CATIA data to be written
                |     when saving Version 5 CATPart documents as CATIA Version 4 models.

        :rtype: str
        """

        return self.interop_setting_att.Code_page

    @code_page.setter
    def code_page(self, value: str):
        """
        :param str value:
        """

        self.interop_setting_att.Code_page = value

    @property
    def conversion_table(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Conversion_Table() As CATBSTR
                | 
                |     Retrieves the location of the "Characters Equivalence Table Path" setting
                |     parameter.
                |     Role: The "Characters Equivalence Table" allows to convert characters
                |     contained in CATIA V4 documents. It is mainly used to generate V5 compliant
                |     names from V4 names by replacing special characters (", *, /, etc...) by
                |     standard characters.

        :rtype: str
        """

        return self.interop_setting_att.Conversion_Table

    @conversion_table.setter
    def conversion_table(self, value: str):
        """
        :param str value:
        """

        self.interop_setting_att.Conversion_Table = value

    @property
    def display_mode(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property DisplayMode() As boolean
                | 
                |     Retrieves or sets the state of the "Display only elements with Sensitive
                |     Attribute" setting parameter.
                |     Role: The "Display only elements with Sensitive Attribute" mode enables you
                |     to decide whether to display or not the elements which were sensitive to the
                |     shading mode in CATIA Version 4.

        :rtype: bool
        """

        return self.interop_setting_att.DisplayMode

    @display_mode.setter
    def display_mode(self, value: bool):
        """
        :param bool value:
        """

        self.interop_setting_att.DisplayMode = value

    @property
    def display_v4_text_3d(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property DisplayV4Text3D() As boolean
                | 
                |     Retrieves or sets the state of the "Display 3D elements labels" setting
                |     parameter.
                |     Role: The "Display 3D elements labels" mode is activated in order to enable
                |     the reading of the 3D text associated to the V4 elements.

        :rtype: bool
        """

        return self.interop_setting_att.DisplayV4Text3D

    @display_v4_text_3d.setter
    def display_v4_text_3d(self, value: bool):
        """
        :param bool value:
        """

        self.interop_setting_att.DisplayV4Text3D = value

    @property
    def dlname(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Dlname() As CATBSTR
                | 
                |     Retrieves or sets the "DLNAME" setting parameter.
                |     Role: Retrieves the DLNAME referenced by the Model.

        :rtype: str
        """

        return self.interop_setting_att.Dlname

    @dlname.setter
    def dlname(self, value: str):
        """
        :param str value:
        """

        self.interop_setting_att.Dlname = value

    @property
    def draw(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Draw() As CATBSTR
                | 
                |     Retrieves or sets the state of the "Open in Light Mode: 2D Data are not
                |     taken into account" setting parameter.
                |     Role: This mode is activated in order to disable the reading of DRAW data
                |     in a V4 Model.

        :rtype: str
        """

        return self.interop_setting_att.Draw

    @draw.setter
    def draw(self, value: str):
        """
        :param str value:
        """

        self.interop_setting_att.Draw = value

    @property
    def project_file_path(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PROJECT_File_Path() As CATBSTR
                | 
                |     Retrieves or sets the value of the "PROJECT File Path" setting
                |     parameter.
                |     Role: The "PROJECT File Path" field contains the location of the external
                |     project file referenced by the V4 model.

        :rtype: str
        """

        return self.interop_setting_att.PROJECT_File_Path

    @project_file_path.setter
    def project_file_path(self, value: str):
        """
        :param str value:
        """

        self.interop_setting_att.PROJECT_File_Path = value

    def get_code_page_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetCode_pageInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the "Reading Code page" setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.interop_setting_att.GetCode_pageInfo(admin_level, o_locked)

    def get_conversion_table_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetConversion_TableInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the "Characters Equivalence Table Path" setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.interop_setting_att.GetConversion_TableInfo(admin_level, o_locked)

    def get_display_mode_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetDisplayModeInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the "Display only elements with Sensitive
                |     Attribute" setting parameter.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.interop_setting_att.GetDisplayModeInfo(admin_level, o_locked)

    def get_display_v4_text_3d_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetDisplayV4Text3DInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the "Display 3D elements labels" setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.interop_setting_att.GetDisplayV4Text3DInfo(admin_level, o_locked)

    def get_dlname_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetDlnameInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the "DlNAME" setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.interop_setting_att.GetDlnameInfo(admin_level, o_locked)

    def get_draw_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetDrawInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the "Open in Light Mode: 2D Data are not taken
                |     into account" setting parameter.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.interop_setting_att.GetDrawInfo(admin_level, o_locked)

    def get_project_file_path_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetPROJECT_File_PathInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the "PROJECT File Path" setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.interop_setting_att.GetPROJECT_File_PathInfo(admin_level, o_locked)

    def set_code_page_lock(self, i_lock: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetCode_pageLock(boolean iLock)
                | 
                |     Locks or unlocks the "Reading Code page" setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_lock:
        :rtype: None
        """
        return self.interop_setting_att.SetCode_pageLock(i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_code_page_lock'
        # # vba_code = """
        # # Public Function set_code_page_lock(interop_setting_att)
        # #     Dim iLock (2)
        # #     interop_setting_att.SetCode_pageLock iLock
        # #     set_code_page_lock = iLock
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_conversion_table_lock(self, i_lock: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetConversion_TableLock(boolean iLock)
                | 
                |     Locks or unlocks the "Characters Equivalence Table Path" setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_lock:
        :rtype: None
        """
        return self.interop_setting_att.SetConversion_TableLock(i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_conversion_table_lock'
        # # vba_code = """
        # # Public Function set_conversion_table_lock(interop_setting_att)
        # #     Dim iLock (2)
        # #     interop_setting_att.SetConversion_TableLock iLock
        # #     set_conversion_table_lock = iLock
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_display_mode_lock(self, i_lock: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetDisplayModeLock(boolean iLock)
                | 
                |     Retrieves information about the "Display only elements with Sensitive
                |     Attribute" setting parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_lock:
        :rtype: None
        """
        return self.interop_setting_att.SetDisplayModeLock(i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_display_mode_lock'
        # # vba_code = """
        # # Public Function set_display_mode_lock(interop_setting_att)
        # #     Dim iLock (2)
        # #     interop_setting_att.SetDisplayModeLock iLock
        # #     set_display_mode_lock = iLock
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_display_v4_text_3d_lock(self, i_lock: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetDisplayV4Text3DLock(boolean iLock)
                | 
                |     Locks or unlocks the "Display 3D elements labels" setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_lock:
        :rtype: None
        """
        return self.interop_setting_att.SetDisplayV4Text3DLock(i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_display_v4_text3_d_lock'
        # # vba_code = """
        # # Public Function set_display_v4_text3_d_lock(interop_setting_att)
        # #     Dim iLock (2)
        # #     interop_setting_att.SetDisplayV4Text3DLock iLock
        # #     set_display_v4_text3_d_lock = iLock
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_dlname_lock(self, i_lock: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetDlnameLock(boolean iLock)
                | 
                |     Locks or unlocks the "DLNAME" setting parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_lock:
        :rtype: None
        """
        return self.interop_setting_att.SetDlnameLock(i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_dlname_lock'
        # # vba_code = """
        # # Public Function set_dlname_lock(interop_setting_att)
        # #     Dim iLock (2)
        # #     interop_setting_att.SetDlnameLock iLock
        # #     set_dlname_lock = iLock
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_draw_lock(self, i_lock: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetDrawLock(boolean iLock)
                | 
                |     Locks or unlocks the "Open in Light Mode: 2D Data are not taken into
                |     account" setting parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_lock:
        :rtype: None
        """
        return self.interop_setting_att.SetDrawLock(i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_draw_lock'
        # # vba_code = """
        # # Public Function set_draw_lock(interop_setting_att)
        # #     Dim iLock (2)
        # #     interop_setting_att.SetDrawLock iLock
        # #     set_draw_lock = iLock
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_project_file_path_lock(self, i_lock: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetPROJECT_File_PathLock(boolean iLock)
                | 
                |     Locks or unlocks the "PROJECT File Path" setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_lock:
        :rtype: None
        """
        return self.interop_setting_att.SetPROJECT_File_PathLock(i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_project_file_path_lock'
        # # vba_code = """
        # # Public Function set_project_file_path_lock(interop_setting_att)
        # #     Dim iLock (2)
        # #     interop_setting_att.SetPROJECT_File_PathLock iLock
        # #     set_project_file_path_lock = iLock
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'InteropSettingAtt(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.reference import Reference
from pycatia.knowledge_interfaces.length import Length
from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape


class HybridShapeCurvePar(HybridShape):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         HybridShapeCurvePar
                | 
                | Represents the hybrid shape curve parameter object.
                | Role: To access the data of the hybrid shape curve parameter object. This data
                | includes:
                | 
                |     The face to process
                |     The offset parameter.
                | 
                | Use the HybridShapeFactory to create a HybridShapeCurvePar
                | object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_curve_par = com_object

    @property
    def curve_offseted(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property CurveOffseted() As Reference
                | 
                |     Returns or sets the offset curve of the curve parameter
                |     object.
                |     Sub-element(s) supported (see Boundary object): see TriDimFeatEdge or
                |     BiDimFeatEdge.
                | 
                |     Example:
                | 
                |           This example retrieves the offset curve of
                |          the hybShpCurvePar in offsetCrv.
                |          
                | 
                |          Dim offsetCrv As CATIAReference
                |          offsetCrv = hybShpCurvePar.CurveOffseted

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_curve_par.CurveOffseted)

    @curve_offseted.setter
    def curve_offseted(self, reference_curve: Reference):
        """
        :param Reference reference_curve:
        """

        self.hybrid_shape_curve_par.CurveOffseted = reference_curve.com_object

    @property
    def curve_par_law(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property CurveParLaw() As Reference
                | 
                |     Returns or sets the offset law.
                | 
                |     Example:
                |         This example retrieves in oLaw the offset law for the hybShpCurvePar
                |         hybrid shape feature.
                | 
                |          Dim oLaw As Reference 
                |          Set oLaw = hybShpCurvePar.CurveParLaw

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_curve_par.CurveParLaw)

    @curve_par_law.setter
    def curve_par_law(self, value: Reference):
        """
        :param Reference value:
        """

        self.hybrid_shape_curve_par.CurveParLaw = value.com_object

    @property
    def curve_par_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property CurveParType() As long
                | 
                |     Returns or sets the corner type.
                |     Legal values:
                | 
                |     0
                |         CATGSMCurvePar_Sharp. corner with angle. 
                |     1
                |         CATGSMCurvePar_Round. round corner.
                | 
                | Example:
                |     This example retrieves in oCurveParType the curve par type for the
                |     hybShpCurvePar hybrid shape feature.
                | 
                |      oCurveParType = hybShpCurvePar.CurveParType

        :rtype: int
        """

        return self.hybrid_shape_curve_par.CurveParType

    @curve_par_type.setter
    def curve_par_type(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_curve_par.CurveParType = value

    @property
    def geodesic(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Geodesic() As boolean
                | 
                |     Returns or sets Geodesic mode.
                |     Legal values: True Geodesic mode and False Euclidian mode
                |     .
                | 
                |     Example:
                | 
                |           This example sets that the geodesic mode of
                |          the hybShpCurvePar hybrid shape curve par feature to
                |          True.
                |          
                | 
                |          hybShpCurvePar.Geodesic = True

        :rtype: bool
        """

        return self.hybrid_shape_curve_par.Geodesic

    @geodesic.setter
    def geodesic(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_curve_par.Geodesic = value

    @property
    def invert_direction(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property InvertDirection() As boolean
                | 
                |     Returns or sets the orientation.
                |     Legal values: True True to invert this orientation and False False means
                |     that there is no invertion of the curve orientation (orientation is the vector
                |     product of the tangent of the curve by the normal on the
                |     support).
                | 
                |     Example:
                | 
                |           This example sets that the orientation of
                |          the hybShpCurvePar hybrid shape curve par feature to
                |          True.
                |          
                | 
                |          hybShpCurvePar.InvertDirection = True

        :rtype: bool
        """

        return self.hybrid_shape_curve_par.InvertDirection

    @invert_direction.setter
    def invert_direction(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_curve_par.InvertDirection = value

    @property
    def invert_mapping_law(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property InvertMappingLaw() As boolean
                | 
                |     Returns or sets the mapping orientation of the law (if offset is specified
                |     by a law).
                |     Legal values: True Law is applied from the end to the beginning of the
                |     curve (mapping is inverted). False Law is applied from the beginning to the end
                |     of the curve (mapping is not inverted).
                | 
                |     Example:
                | 
                |           This example sets that the mapping orientation of
                |          the hybShpCurvePar hybrid shape curve par feature to
                |          True.
                |          
                | 
                |          hybShpCurvePar.InvertMappingLaw = True

        :rtype: bool
        """

        return self.hybrid_shape_curve_par.InvertMappingLaw

    @invert_mapping_law.setter
    def invert_mapping_law(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_curve_par.InvertMappingLaw = value

    @property
    def keep_both_sides(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property KeepBothSides() As boolean
                | 
                |     Returns or sets the both sides mode of the curve parameter
                |     object.
                | 
                |     Example:
                | 
                |           This example retrieves the both sides mode of
                |          the hybShpCurvePar
                |          
                | 
                |          Dim bothSides As Boolean
                |          bothSides = hybShpCurvePar.KeepBothSides

        :rtype: bool
        """

        return self.hybrid_shape_curve_par.KeepBothSides

    @keep_both_sides.setter
    def keep_both_sides(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_curve_par.KeepBothSides = value

    @property
    def law_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property LawType() As long
                | 
                |     Returns or sets the law type.
                |     Legal values:
                | 
                |     0
                |         CATGSMBasicLawType_None. Undefined law type. 
                |     1
                |         CATGSMBasicLawType_Constant. Constant law type.
                |     2
                |         CATGSMBasicLawType_Linear. Linear law type.
                |     3
                |         CATGSMBasicLawType_SType. S law type.
                |     4
                |         CATGSMBasicLawType_Advanced. Law specified by a GSD law
                |         feature.
                | 
                | Example:
                |     This example retrieves in oLawType the law type for the hybShpCurvePar
                |     hybrid shape feature.
                | 
                |      oLawType = hybShpCurvePar.LawType

        :rtype: int
        """

        return self.hybrid_shape_curve_par.LawType

    @law_type.setter
    def law_type(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_curve_par.LawType = value

    @property
    def maximum_deviation_value(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property MaximumDeviationValue() As double
                | 
                |     Sets or Gets the maximum deviation allowed for smoothing
                |     operation.
                |     Sets in distance unit, it corresponds to the radius of a pipe around the
                |     input curve in which the result is allowed to be. This value must be set in SI
                |     unit (m).
                | 
                |     Example: This example retrieves in DeviationValue the maximum deviation
                |     value for the CurvePar hybrid shape feature.
                | 
                |      Dim DeviationValue As CATIALength
                |      Set DeviationValue = CurvePar.MaximumDeviationValue

        :rtype: float
        """

        return self.hybrid_shape_curve_par.MaximumDeviationValue

    @maximum_deviation_value.setter
    def maximum_deviation_value(self, value: float):
        """
        :param float value:
        """

        self.hybrid_shape_curve_par.MaximumDeviationValue = value

    @property
    def offset(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Offset() As Length (Read Only)
                | 
                |     Returns the offset parameter of the curve parameter
                |     object.
                | 
                |     Example:
                | 
                |           This example retrieves the offset parameter of
                |          the hybShpCurvePar in offsetParm.
                |          
                | 
                |          Dim offsetParm As CATIALength
                |          offsetParm = hybShpCurvePar.Offset

        :rtype: Length
        """

        return Length(self.hybrid_shape_curve_par.Offset)

    @property
    def offset2(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Offset2() As Length (Read Only)
                | 
                |     Returns the second offset parameter of the curve parameter
                |     object.
                | 
                |     Example:
                | 
                |           This example retrieves the second offset parameter
                |           of
                |          the hybShpCurvePar in offsetParm.
                |          
                | 
                |          Dim offsetParm As CATIALength
                |          offsetParm = hybShpCurvePar.Offset2

        :rtype: Length
        """

        return Length(self.hybrid_shape_curve_par.Offset2)

    @property
    def other_side(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property OtherSide() As Reference (Read Only)
                | 
                |     Returns the other side of parallel curve if both sides mode is
                |     on.
                | 
                |     Example:
                | 
                |           This example retrieves the other side of
                |          the hybShpCurvePar
                |          
                | 
                |          Dim otherSide As CATIAReference
                |          Set otherSide = hybShpCurvePar.OtherSide

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_curve_par.OtherSide)

    @property
    def passing_point(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property PassingPoint() As Reference
                | 
                |     Returns or sets the passing point of the curve parameter
                |     object.
                |     Sub-element(s) supported (see Point object):
                | 
                |     Example:
                | 
                |           This example retrieves the offset curve of
                |          the hybShpCurvePar in offsetCrv.
                |          
                | 
                |          Dim PassingPoint As CATIAReference
                |          offsetCrv = hybShpCurvePar.PassingPoint

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_curve_par.PassingPoint)

    @passing_point.setter
    def passing_point(self, reference_point: Reference):
        """
        :param Reference reference_point:
        """

        self.hybrid_shape_curve_par.PassingPoint = reference_point.com_object

    @property
    def smoothing_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SmoothingType() As long
                | 
                |     Returns or sets the smoothing Type.
                |     Smoothing type:
                | 
                |         : 0 -> No Smoothing
                |         : 2 -> G1 Smoothing : Enhance current continuity to tangent continuity
                |         : 3 -> G2 Smoothing : Enhance current continuity to curvature continuity
                | 
                |     Example: This example retrieves in SType the smoothing type for the
                |     CurvePar hybrid shape feature.
                | 
                |      Dim SType As long
                |      Set SType = CurvePar.SmoothingType

        :rtype: int
        """

        return self.hybrid_shape_curve_par.SmoothingType

    @smoothing_type.setter
    def smoothing_type(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_curve_par.SmoothingType = value

    @property
    def support(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Support() As Reference
                | 
                |     Returns or sets the support of the curve..
                | 
                |     Example:
                |         This example retrieves in oElem the support of the curve for the
                |         hybShpCurvePar hybrid shape feature.
                | 
                |          Dim oElem As Reference 
                |          Set oElem = hybShpCurvePar.Support

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_curve_par.Support)

    @support.setter
    def support(self, reference_support: Reference):
        """
        :param Reference reference_support:
        """

        self.hybrid_shape_curve_par.Support = reference_support.com_object

    @property
    def p_3d_smoothing(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property p3DSmoothing() As boolean
                | 
                |     Returns or sets the '3D Smoothing' option. Role: To activate or not the 3D smoothing option
                |     Available only for tangent or curvature smoothing type TRUE : Smoothing performed without
                |     specifying support FALSE : Smoothing performed with specific support
                | 
                |     Example: This example retrieves in 3DSmoothingOption the support for the
                |     Project hybrid shape feature.
                | 
                |      Dim 3DSmoothingOption As boolean
                |      Set 3DSmoothingOption = Project.p3DSmoothing

        :rtype: bool
        """

        return self.hybrid_shape_curve_par.p3DSmoothing

    @p_3d_smoothing.setter
    def p_3d_smoothing(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_curve_par.p3DSmoothing = value

    def get_plane_normal(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetPlaneNormal(CATSafeArrayVariant oNormal)
                | 
                |     Returns the Normal of the plane created when the Support of the curve is
                |     not specified.
                | 
                |     Parameters:
                | 
                |         oNormal
                |             Plane normal. It is returned as an array of three coordinates in
                |             SafeArrayVariant 
                | 
                |     Example:
                |         This example retrieves in oNormal the normal of the hybShpCurvePar
                |         plane created.
                | 
                |          Dim oNormal(2)
                |          hybShpCurvePar.GetPlaneNormal(oNormal)
                |          
                | 
                |         You can access each normal coordinate as follows:
                | 
                |             x is in oNormal(0)
                |             y is in oNormal(1)
                |             z is in oNormal(2)

        :rtype: tuple
        """
        vba_function_name = 'get_plane_normal'
        vba_code = """
        Public Function get_plane_normal(hybrid_shape_curve_par)
            Dim oNormal (2)
            hybrid_shape_curve_par.GetPlaneNormal oNormal
            get_plane_normal = oNormal
        End Function
        """

        system_service = self.application.system_service
        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def put_plane_normal(self, i_normal: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub PutPlaneNormal(CATSafeArrayVariant iNormal)
                | 
                |     Sets the Normal of the plane created when the Support of the curve is not
                |     specified.
                | 
                |     Parameters:
                | 
                |         iNormal
                |         iNormal[0]
                |             The X Coordinate of the normal vector 
                |         iNormal[1]
                |             The Y Coordinate of the normal vector 
                |         iNormal[2]
                |             The Z Coordinate of the normal vector

        :param tuple i_normal:
        :rtype: None
        """
        return self.hybrid_shape_curve_par.PutPlaneNormal(i_normal)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'put_plane_normal'
        # # vba_code = """
        # # Public Function put_plane_normal(hybrid_shape_curve_par)
        # #     Dim iNormal (2)
        # #     hybrid_shape_curve_par.PutPlaneNormal iNormal
        # #     put_plane_normal = iNormal
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'HybridShapeCurvePar(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_app_connectable import SchAppConnectable
from pycatia.cat_sch_platform_interfaces.sch_list_of_objects import SchListOfObjects
from pycatia.system_interfaces.any_object import AnyObject


class SchNetworkAnalysis(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchNetworkAnalysis
                | 
                | Represents a schematic network.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_network_analysis = com_object

    def find_paths(self, i_from_object: SchAppConnectable, i_to_object: SchAppConnectable) -> SchListOfObjects:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func FindPaths(SchAppConnectable iFromObject,
                | SchAppConnectable iToObject) As SchListOfObjects
                | 
                |     Given a start and end object in the network, this method returns a list of
                |     network objects each representing a path connecting the the 2 input
                |     objects.
                | 
                |     Parameters:
                | 
                |         iFromObject
                |             The connectable to start from. 
                |         iToObject
                |             The connectable to finish at. 
                |         oLNetworks
                |             Pointer to a list of networks. (Members are CATISchNetworkAnalysis
                |             interface pointers). 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchNetworkAnalysis
                |          Dim objArg1 As SchAppConnectable
                |          Dim objArg2 As SchAppConnectable
                |          Dim objArg3 As SchListOfObjects
                |           ...
                |          Set objArg3 = objThisIntf.FindPaths(objArg1,objArg2)

        :param SchAppConnectable i_from_object:
        :param SchAppConnectable i_to_object:
        :rtype: SchListOfObjects
        """
        return SchListOfObjects(self.sch_network_analysis.FindPaths(i_from_object.com_object, i_to_object.com_object))

    def list_extremity_objects(self) -> SchListOfObjects:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ListExtremityObjects() As SchListOfObjects
                | 
                |     List the extremity objects of the network.
                | 
                |     Parameters:
                | 
                |         oLExtremityObjs
                |             Pointer to a list of extremity objects of the network (Members are
                |             CATISchAppConnectable interface pointers). 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchNetworkAnalysis
                |          Dim objArg1 As SchListOfObjects
                |           ...
                |          Set objArg1 = objThisIntf.ListExtremityObjects

        :rtype: SchListOfObjects
        """
        return SchListOfObjects(self.sch_network_analysis.ListExtremityObjects())

    def list_network_objects(self) -> SchListOfObjects:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ListNetworkObjects() As SchListOfObjects
                | 
                |     List the connected objects in the network.
                | 
                |     Parameters:
                | 
                |         oLNetworkObjs
                |             Pointer to a list of all connected objects in the network. (Members
                |             are CATISchAppConnectable interface pointers) 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchNetworkAnalysis
                |          Dim objArg1 As SchListOfObjects
                |           ...
                |          Set objArg1 = objThisIntf.ListNetworkObjects

        :rtype: SchListOfObjects
        """
        return SchListOfObjects(self.sch_network_analysis.ListNetworkObjects())

    def __repr__(self):
        return f'SchNetworkAnalysis(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dnb_human_sim_interfaces.human_task import HumanTask
from pycatia.dnb_human_sim_interfaces.human_task_list import HumanTaskList
from pycatia.system_interfaces.any_object import AnyObject


class HumanProgram(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     HumanProgram
                | 
                | The object that represents program-node of Worker.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.human_program = com_object

    @property
    def task_list(self) -> HumanTaskList:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TaskList() As HumanTaskList (Read Only)
                | 
                |     Returns the HumanTaskList from HumanProgram
                | 
                |     Returns:
                |         oTaskList

        :rtype: HumanTaskList
        """

        return HumanTaskList(self.human_program.TaskList)

    def create_human_task(self) -> HumanTask:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateHumanTask() As HumanTask
                | 
                |     Returns newly created HumanTask.
                | 
                |     Returns:
                |         oManikin

        :rtype: HumanTask
        """
        return HumanTask(self.human_program.CreateHumanTask())

    def __repr__(self):
        return f'HumanProgram(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.knowledge_interfaces.check import Check
from pycatia.knowledge_interfaces.real_param import RealParam


class OptimizationConstraint(Check):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     KnowledgeInterfaces.KnowledgeObject
                |                        KnowledgeInterfaces.KnowledgeActivateObject
                |                             KnowledgeInterfaces.Relation
                |                                 KnowledgeInterfaces.Check
                |                                     OptimizationConstraint
                | 
                | Represents an optimization constraint.
                | 
                | See also:
                |     OptimizationConstraints
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.optimization_constraint = com_object

    @property
    def distance_to_satisfaction(self) -> RealParam:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property DistanceToSatisfaction() As RealParam (Read Only)
                | 
                |     Returns the parameter containing the distance to constraint satisfaction.

        :rtype: RealParam
        """

        return RealParam(self.optimization_constraint.DistanceToSatisfaction)

    @property
    def precision(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Precision() As double
                | 
                |     Returns or sets the constraint precision. Only for equality
                |     constraints.
                |     The constraint precision allows the system to know when an equality constraint can be declared as
                |     satisfied (when : distance to satisfaction < precision).

        :rtype: float
        """

        return self.optimization_constraint.Precision

    @precision.setter
    def precision(self, value: float):
        """
        :param float value:
        """

        self.optimization_constraint.Precision = value

    @property
    def satisfaction(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Satisfaction() As boolean (Read Only)
                | 
                |     Returns the constraint satisfaction.

        :rtype: bool
        """

        return self.optimization_constraint.Satisfaction

    def __repr__(self):
        return f'OptimizationConstraint(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_str_functional_interfaces.sfm_connection_parameters import SFMConnectionParameters
from pycatia.cat_str_functional_interfaces.sfm_endcut_manager import SFMEndcutManager
from pycatia.cat_str_functional_interfaces.sfm_profile import SFMProfile
from pycatia.mec_mod_interfaces.factory import Factory
from pycatia.types.general import cat_variant


class SFMOperationFactory(Factory):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.Factory
                |                         SfmOperationFactory
                | 
                | Gets the Operation Factory.
                | 
                | Example:
                |     This Example Retrieves SfmOperationFactory from Part.
                | 
                |      Set part1 = partDocument1.Part
                |      Dim Factory As SfmOperationFactory
                |      Set Factory =  part1.GetCustomerFactory("SfmOperationFactory")
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sfm_operation_factory = com_object

    def get_available_slots_from_catalog(self, i_sfm_profile: SFMProfile) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAvailableSlotsFromCatalog(SfmProfile iSfmProfile) As
                | CATSafeArrayVariant
                | 
                |     Gets the list of available Slots from catalog for a given
                |     Profile(Stiffener/Member).
                | 
                |     Parameters:
                | 
                |         iSfmProfile
                |             [in] The given profile. 
                |         oListofSlotNames
                |             [out] The List of Slots available. 
                | 
                |     Returns:
                |         S_OK if everything ran ok
                | 
                |         Example:
                |             This Example retrieves the list of avaliable
                |             Slots.
                | 
                |              Dim FactoryObj As SfmOperationFactory
                |              Set FactoryObj = PartObj.GetCustomerFactory("SfmOperationFactory")
                |              Dim ListOfAvailableSlots() As Variant
                |              ListOfAvailableSlots = SlotFactoryObj.GetAvailableSlotsFromCatalog(SfmProfileObj)

        :param SFMProfile i_sfm_profile:
        :rtype: tuple
        """
        return self.sfm_operation_factory.GetAvailableSlotsFromCatalog(i_sfm_profile.com_object)

    def get_endcut_manager(self) -> SFMEndcutManager:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetEndcutManager() As SfmEndcutManager
                | 
                |     Gets the Endcut Manager.
                | 
                |     Parameters:
                | 
                |         oSfmEndcutManager
                |             [out] The retrieved Manager. 
                | 
                |     Returns:
                |         S_OK if everything ran ok
                | 
                |         Example:
                |             This Example retrieves the Endcut Manager from the
                |             Factory.
                | 
                |              Dim FactoryObj As SfmOperationFactory
                |              Set FactoryObj = PartObj.GetCustomerFactory("SfmOperationFactory")
                |              Dim EndCutManagerObj As SfmEndcutManager
                |              Set EndCutManagerObj = FactoryObj.GetEndcutManager

        :rtype: SFMEndcutManager
        """
        return SFMEndcutManager(self.sfm_operation_factory.GetEndcutManager())

    def get_slot_parameters(
            self,
            i_sfm_profile: SFMProfile,
            i_slot_name: str,
            o_list_slot_parameters: SFMConnectionParameters,
            o_list_slot_param_names: tuple
    ) -> cat_variant:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetSlotParameters(SfmProfile iSfmProfile,
                | CATBSTR iSlotName,
                | SfmConnectionParameters oListSlotParameters,
                | CATSafeArrayVariant oListSlotParamNames)
                | 
                |     Gets the Slot Parameters and Names for a slot from
                |     catalog.
                | 
                |     Parameters:
                | 
                |         iSfmProfile
                |             [in] The given profile. 
                |         iSlotName
                |             [in] Name of the Slot. 
                |         oListSlotParameters
                |             [out] The Slot UDF Parameters with deafult values.
                |             
                |         oListSlotParamNames
                |             [out] Slot Parameter Names. 
                | 
                |     Returns:
                |         S_OK if everything ran ok
                | 
                |         Example:
                |             This Example retrieves Parameters for Slot.
                | 
                |              Dim FactoryObj As SfmOperationFactory
                |              Set FactoryObj = PartObj.GetCustomerFactory("SfmOperationFactory")
                |              Dim oListSlotParams As SfmConnectionParameters
                |              Dim oListSlotPramNames() As Variant
                |              SlotFactoryObj.GetSlotParameters SfmProfileObj,
                |              "Tee_Slot_thru_Plate", oListSlotParams,
                |              oListSlotPramNames
                |              'Reading Slot Param Values
                |              Dim UDFParam As Parameter
                |              ParamCount = oListSlotParams.Count
                |              For i = 1 To ParamCount
                |              Set UDFParam = oListSlotParams.Item(i)
                |              ParamName = oListSlotPramNames(i - 1)
                |              ParamValue = UDFParam.ValueAsString
                |              End If
                |              Next

        :param SFMProfile i_sfm_profile:
        :param str i_slot_name:
        :param SFMConnectionParameters o_list_slot_parameters:
        :param tuple o_list_slot_param_names:
        :rtype: cat_variant
        """
        return self.sfm_operation_factory.GetSlotParameters(
            i_sfm_profile.com_object,
            i_slot_name,
            o_list_slot_parameters.com_object,
            o_list_slot_param_names)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_slot_parameters'
        # # vba_code = """
        # # Public Function get_slot_parameters(sfm_operation_factory)
        # #     Dim iSfmProfile (2)
        # #     sfm_operation_factory.GetSlotParameters iSfmProfile
        # #     get_slot_parameters = iSfmProfile
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SFMOperationFactory(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dmaps_interfaces.activity import Activity
from pycatia.dnb_dpm_interfaces.mfg_assembly import MfgAssembly
from pycatia.dnb_human_sim_interfaces.worker_activity import WorkerActivity
from pycatia.product_structure_interfaces.product import Product


class PlaceActivity(WorkerActivity):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DMAPSInterfaces.Activity
                |                         DNBHumanSimInterfaces.WorkerActivity
                |                             PlaceActivity
                | 
                | The object that represents an PlaceActivity.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.place_activity = com_object

    def add_placed_mfg_assembly(self, p_picked_item: MfgAssembly, vb_sav: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddPlacedMfgAssembly(MfgAssembly pPickedItem,
                | CATSafeArrayVariant vbSAV)
                | 
                |     Adds a Manufacturing Assembly to the List of placed Items

        :param MfgAssembly p_picked_item:
        :param tuple vb_sav:
        :rtype: None
        """
        return self.place_activity.AddPlacedMfgAssembly(p_picked_item.com_object, vb_sav)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_placed_mfg_assembly'
        # # vba_code = """
        # # Public Function add_placed_mfg_assembly(place_activity)
        # #     Dim pPickedItem (2)
        # #     place_activity.AddPlacedMfgAssembly pPickedItem
        # #     add_placed_mfg_assembly = pPickedItem
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_placed_product(self, p_picked_item: Product, vb_sav: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddPlacedProduct(Product pPickedItem,
                | CATSafeArrayVariant vbSAV)
                | 
                |     Adds a product to the List of placed Items

        :param Product p_picked_item:
        :param tuple vb_sav:
        :rtype: None
        """
        return self.place_activity.AddPlacedProduct(p_picked_item.com_object, vb_sav)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_placed_product'
        # # vba_code = """
        # # Public Function add_placed_product(place_activity)
        # #     Dim pPickedItem (2)
        # #     place_activity.AddPlacedProduct pPickedItem
        # #     add_placed_product = pPickedItem
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_offset(self, o_offset_trans_list: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetOffset(CATSafeArrayVariant oOffsetTransList)
                | 
                |     This method gets the relative offset List for placing the
                |     product
                | 
                |     Parameters:
                | 
                |         oOffsetTrans
                |             list of Offsets between EndEff and Product at time of placing first
                |             12 values represent 1st offset, next 12, 2nd offset and so on.. The offset
                |             matrix is interpreted as follows: The first 9 entries correspond to the
                |             rotation matrix and the next 3 entries correspond to the position vector The
                |             first 9 entries are interpreted row wise for the matrix shown
                |             below
                |             R1x R1y R1z
                |             R2x R2y R2z
                |             R3x R3y R3z
                |             Px Py Pz
                |             R1x:x-component of x axis
                |             R2x:y-component of x axis
                |             R3x:z-component of x axis
                |             R1y:x-component of y axis
                |             R2y:y-component of y axis
                |             R3y:z-component of y axis
                |             R1z:x-component of z axis
                |             R2z:y-component of z axis
                |             R3z:z-component of z axis

        :param tuple o_offset_trans_list:
        :rtype: None
        """
        return self.place_activity.GetOffset(o_offset_trans_list)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_offset'
        # # vba_code = """
        # # Public Function get_offset(place_activity)
        # #     Dim oOffsetTransList (2)
        # #     place_activity.GetOffset oOffsetTransList
        # #     get_offset = oOffsetTransList
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_placed_products(self, p_placed_prods: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetPlacedProducts(CATSafeArrayVariant pPlacedProds)
                | 
                |     Returns or Sets Placed Products

        :param tuple p_placed_prods:
        :rtype: None
        """
        return self.place_activity.GetPlacedProducts(p_placed_prods)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_placed_products'
        # # vba_code = """
        # # Public Function get_placed_products(place_activity)
        # #     Dim pPlacedProds (2)
        # #     place_activity.GetPlacedProducts pPlacedProds
        # #     get_placed_products = pPlacedProds
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def remove_placed_mfg_assembly(self, p_picked_item: MfgAssembly) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemovePlacedMfgAssembly(MfgAssembly pPickedItem)
                | 
                |     Removes a Manufacturing Assembly from the list of placed items

        :param MfgAssembly p_picked_item:
        :rtype: None
        """
        return self.place_activity.RemovePlacedMfgAssembly(p_picked_item.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove_placed_mfg_assembly'
        # # vba_code = """
        # # Public Function remove_placed_mfg_assembly(place_activity)
        # #     Dim pPickedItem (2)
        # #     place_activity.RemovePlacedMfgAssembly pPickedItem
        # #     remove_placed_mfg_assembly = pPickedItem
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def remove_placed_product(self, p_picked_item: Product) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemovePlacedProduct(Product pPickedItem)
                | 
                |     Removes a product from the list of placed items

        :param Product p_picked_item:
        :rtype: None
        """
        return self.place_activity.RemovePlacedProduct(p_picked_item.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove_placed_product'
        # # vba_code = """
        # # Public Function remove_placed_product(place_activity)
        # #     Dim pPickedItem (2)
        # #     place_activity.RemovePlacedProduct pPickedItem
        # #     remove_placed_product = pPickedItem
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_offset(self, o_offset_trans_list: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetOffset(CATSafeArrayVariant oOffsetTransList)
                | 
                |     This method sets the relative offsets for placing the
                |     product
                | 
                |     Parameters:
                | 
                |         oOffsetTransList
                |             list of Offsets between EndEffs and Products at time of placing
                |             first 12 values represent 1st offset, next 12, 2nd offset and so on.. The offset
                |             matrix is interpreted as follows: The first 9 entries correspond to the
                |             rotation matrix and the next 3 entries correspond to the position
                |             vector
                |             R1x R1y R1z
                |             R2x R2y R2z
                |             R3x R3y R3z
                |             Px Py Pz
                |             R1x:x-component of x axis
                |             R2x:y-component of x axis
                |             R3x:z-component of x axis
                |             R1y:x-component of y axis
                |             R2y:y-component of y axis
                |             R3y:z-component of y axis
                |             R1z:x-component of z axis
                |             R2z:y-component of z axis
                |             R3z:z-component of z axis
                | 
                |     Example:
                | 
                |           This example shows how the offset list needs to be
                |           populated
                |
                |          ' Example of 45 degree rotation around the x-axis of placing
                |          hand
                |         Dim oOffsetTransList(11) ' 0 to 11; relative transformation between
                |         hand and object
                |         ' X axis rotation component
                |         oOffsetTransList( 0 )  = 1
                |         oOffsetTransList( 3 )  = 0
                |         oOffsetTransList( 6 )  = 0
                |         ' Y axis rotation component
                |         oOffsetTransList( 1 )  = 0
                |         oOffsetTransList( 4 )  = 0.7071
                |         oOffsetTransList( 7 )  = 0.7071
                |         ' Z axis rotation component
                |         oOffsetTransList( 2 )  = 0
                |         oOffsetTransList( 5 )  = -0.7071
                |         oOffsetTransList( 8 )  = 0.7071
                |         ' position vector (relative vector between the hand and
                |         object)
                |         oOffsetTransList( 9 )  = 0
                |         oOffsetTransList( 10 )  = 0
                |         oOffsetTransList( 11 )  = 0

        :param tuple o_offset_trans_list:
        :rtype: None
        """
        return self.place_activity.SetOffset(o_offset_trans_list)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_offset'
        # # vba_code = """
        # # Public Function set_offset(place_activity)
        # #     Dim oOffsetTransList (2)
        # #     place_activity.SetOffset oOffsetTransList
        # #     set_offset = oOffsetTransList
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_pick_act(self, pick_act: Activity) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetPickAct(Activity pickAct)
                | 
                |     Sets or append a link to a Pick activity

        :param Activity pick_act:
        :rtype: None
        """
        return self.place_activity.SetPickAct(pick_act.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_pick_act'
        # # vba_code = """
        # # Public Function set_pick_act(place_activity)
        # #     Dim pickAct (2)
        # #     place_activity.SetPickAct pickAct
        # #     set_pick_act = pickAct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_placed_products(self, p_placed_prods: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetPlacedProducts(CATSafeArrayVariant pPlacedProds)

        :param tuple p_placed_prods:
        :rtype: None
        """
        return self.place_activity.SetPlacedProducts(p_placed_prods)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_placed_products'
        # # vba_code = """
        # # Public Function set_placed_products(place_activity)
        # #     Dim pPlacedProds (2)
        # #     place_activity.SetPlacedProducts pPlacedProds
        # #     set_placed_products = pPlacedProds
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'PlaceActivity(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import TYPE_CHECKING

from pycatia.general_knowledge_interfaces.expert_rule_base_component_runtime import ExpertRuleBaseComponentRuntime

if TYPE_CHECKING:
    from pycatia.general_knowledge_interfaces.expert_rule import ExpertRule


class ExpertRuleRuntime(ExpertRuleBaseComponentRuntime):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                    GenKnowledgeInterfaces.ExpertRuleBaseComponentRuntime
                |                         ExpertRuleRuntime
                | 
                | Represents the ExpertRuleRuntime object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.expert_rule_runtime = com_object

    @property
    def priority(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Priority() As double
                | 
                |     Returns or sets the priority of the rule. The priority of expert rules
                |     indicates the order in which the rules are evaluated. Rules with the same
                |     priority are evaluated in the order of their creation.

        :rtype: float
        """

        return self.expert_rule_runtime.Priority

    @priority.setter
    def priority(self, value: float):
        """
        :param float value:
        """

        self.expert_rule_runtime.Priority = value

    @property
    def rule_edition(self) -> 'ExpertRule':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property RuleEdition() As ExpertRule (Read Only)
                | 
                |     Returns the editable object corresponding to this rule. Be careful that, according to your licence, or the type of rule you're handling, you may not have the right to edit the rule. Dim aRuleEdition As ExpertRule Set aRuleEdition = aRuleRuntime.RuleEdition If not(aRuleEdition is Nothing) Then CATIA.SystemService.Print aRuleEdition.Body End if

        :rtype: ExpertRule
        """
        
        from pycatia.general_knowledge_interfaces.expert_rule import ExpertRule
        return ExpertRule(self.expert_rule_runtime.RuleEdition)

    def __repr__(self):
        return f'ExpertRuleRuntime(name="{self.name}")'
